@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2013-2024 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2025 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -43,7 +43,7 @@
 #include <QPointer>
 #include <QStatusBar>
 #include <QToolButton>
-#ifdef WITH_KUSERFEEDBACK
+#if WITH_KUSERFEEDBACK
 #include "userfeedback/userfeedbackmanager.h"
 #include <KUserFeedback/NotificationPopup>
 #include <KUserFeedback/Provider>
@@ -55,7 +55,11 @@
 #include <unistd.h>
 #endif
 #include <KWindowConfig>
+#include <KWindowSystem>
 #include <QWindow>
+#if defined(Q_OS_WIN) || defined(Q_OS_MACOS)
+#include <PimCommon/VerifyNewVersionWidget>
+#endif
 
 namespace
 {
@@ -63,6 +67,10 @@ static const char mySieveEditorMainWindowConfigGroupName[] = "SieveEditorMainWin
 }
 SieveEditorMainWindow::SieveEditorMainWindow(QWidget *parent)
     : KXmlGuiWindow(parent)
+#if defined(Q_OS_WIN) || defined(Q_OS_MACOS)
+    , mVerifyNewVersionWidget(new PimCommon::VerifyNewVersionWidget(this))
+#endif
+
 {
 #ifdef Q_OS_UNIX
     /**
@@ -93,7 +101,7 @@ SieveEditorMainWindow::SieveEditorMainWindow(QWidget *parent)
 
     mMainWidget = new SieveEditorCentralWidget(this, actionCollection());
     mainWidgetLayout->addWidget(mMainWidget);
-#ifdef WITH_KUSERFEEDBACK
+#if WITH_KUSERFEEDBACK
     // Initialize
     (void)UserFeedBackManager::self();
 #endif
@@ -118,7 +126,7 @@ SieveEditorMainWindow::SieveEditorMainWindow(QWidget *parent)
     connect(mMainWidget->sieveEditorMainWidget(), &SieveEditorMainWidget::copyAvailable, this, &SieveEditorMainWindow::slotCopyAvailable);
     connect(mMainWidget->sieveEditorMainWidget(), &SieveEditorMainWidget::sieveEditorTabCurrentChanged, this, &SieveEditorMainWindow::slotUpdateActions);
     mMainWidget->sieveEditorMainWidget()->refreshList();
-#ifdef WITH_KUSERFEEDBACK
+#if WITH_KUSERFEEDBACK
     auto userFeedBackNotificationPopup = new KUserFeedback::NotificationPopup(this);
     userFeedBackNotificationPopup->setFeedbackProvider(UserFeedBackManager::self()->userFeedbackProvider());
 #endif
@@ -326,7 +334,7 @@ void SieveEditorMainWindow::setupActions()
             disconnect(mHamburgerMenu, &KHamburgerMenu::aboutToShowMenu, this, nullptr);
         });
     }
-    act = new QAction(i18nc("@action", "Import IMAP Settings…"), this);
+    act = new QAction(QIcon::fromTheme(QStringLiteral("document-import")), i18nc("@action", "Import IMAP Settings…"), this);
     ac->addAction(QStringLiteral("import_imap_settings"), act);
     connect(act, &QAction::triggered, this, &SieveEditorMainWindow::slotImportImapSettings);
 
@@ -334,12 +342,35 @@ void SieveEditorMainWindow::setupActions()
     ac->setDefaultShortcut(mShowFullScreenAction, Qt::Key_F11);
     connect(mShowFullScreenAction, &QAction::toggled, this, &SieveEditorMainWindow::slotFullScreen);
 
+#if defined(Q_OS_WIN) || defined(Q_OS_MACOS)
+#if SIEVEEDITOR_STABLE_VERSION
+    const QString url = QStringLiteral("https://cdn.kde.org/ci-builds/pim/pim-sieve-editor/25.04/windows/");
+#else
+    const QString url = QStringLiteral("https://cdn.kde.org/ci-builds/pim/pim-sieve-editor/master/windows/");
+#endif
+    mVerifyNewVersionWidget->addOsUrlInfo(PimCommon::VerifyNewVersionWidget::OsVersion::Windows, url);
+    auto verifyNewVersionAction = mVerifyNewVersionWidget->verifyNewVersionAction();
+    ac->addAction(QStringLiteral("verify_check_version"), verifyNewVersionAction);
+#endif
+
     auto manager = KColorSchemeManager::instance();
     ac->addAction(QStringLiteral("colorscheme_menu"), KColorSchemeMenu::createMenu(manager, this));
     mShowMenuBarAction->setChecked(SieveEditorGlobalConfig::self()->showMenuBar());
     slotToggleMenubar(true);
 }
 
+void SieveEditorMainWindow::slotActivateRequested(const QStringList &arguments, const QString &workingDirectory)
+{
+    Q_UNUSED(workingDirectory)
+    // TODO arguments
+#if !defined(Q_OS_WIN) && !defined(Q_OS_MACOS)
+    KWindowSystem::updateStartupId(windowHandle());
+    KWindowSystem::activateWindow(windowHandle());
+#else
+    activateWindow();
+#endif
+}
+
 void SieveEditorMainWindow::slotToggleMenubar(bool dontShowWarning)
 {
     if (menuBar()) {
